@@ -14,18 +14,18 @@
 
 #include <utils/applicationstate.h>
 
-#include <Libkleo/GnuPG>
 #include <Libkleo/Formatting>
+#include <Libkleo/GnuPG>
 
 #include <gpgme++/key.h>
 
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <QProcess>
-#include <QTextStream>
 #include <QFile>
 #include <QFileDialog>
+#include <QProcess>
+#include <QTextStream>
 
 #include "command_p.h"
 #include "kleopatra_debug.h"
@@ -34,8 +34,8 @@ using namespace Kleo;
 using namespace Kleo::Commands;
 using namespace GpgME;
 
-GenRevokeCommand::GenRevokeCommand(QAbstractItemView *v, KeyListController *c) :
-    GnuPGProcessCommand(v, c)
+GenRevokeCommand::GenRevokeCommand(QAbstractItemView *v, KeyListController *c)
+    : GnuPGProcessCommand(v, c)
 {
 }
 
@@ -56,46 +56,47 @@ void GenRevokeCommand::postSuccessHook(QWidget *parentWidget)
 
     if (!f.open(QIODevice::ReadOnly)) {
         // Should never happen because in this case we would not have had a success.
-        KMessageBox::error(parentWidget, errorCaption(),
-                           QStringLiteral("Failed to access the created output file."));
+        KMessageBox::error(parentWidget, QStringLiteral("Failed to access the created output file."), errorCaption());
         return;
     }
     const QString revCert = QString::fromLocal8Bit(f.readAll());
     f.close();
 
     if (!f.open(QIODevice::WriteOnly)) {
-        KMessageBox::error(parentWidget, errorCaption(),
-                           QStringLiteral("Failed to write to the created output file."));
+        KMessageBox::error(parentWidget, QStringLiteral("Failed to write to the created output file."), errorCaption());
         return;
     }
 
     QTextStream s(&f);
 
-    s << i18n("This is a revocation certificate for the OpenPGP key:")
-      << "\n\n             " << Formatting::prettyNameAndEMail(d->key())
-      <<   "\n Fingerprint: " << d->key().primaryFingerprint() << "\n\n"
-      << i18n("A revocation certificate is a kind of \"kill switch\" to publicly\n"
-              "declare that a key shall not anymore be used.  It is not possible\n"
-              "to retract such a revocation certificate once it has been published.")
+    s << i18n("This is a revocation certificate for the OpenPGP key:") << "\n\n" //
+      << "             " << Formatting::prettyNameAndEMail(d->key()) << "\n" //
+      << "Fingerprint: " << d->key().primaryFingerprint() << "\n\n"
+      << i18n(
+             "A revocation certificate is a kind of \"kill switch\" to publicly\n"
+             "declare that a key shall not anymore be used.  It is not possible\n"
+             "to retract such a revocation certificate once it has been published.")
       << "\n\n"
-      << i18n("Use it to revoke this key in case of a compromise or loss of\n"
-              "the secret key.")
+      << i18n(
+             "Use it to revoke this key in case of a compromise or loss of\n"
+             "the secret key.")
       << "\n\n"
-      << i18n("To avoid an accidental use of this file, a colon has been inserted\n"
-              "before the 5 dashes below.  Remove this colon with a text editor\n"
-              "before importing and publishing this revocation certificate.")
-      << "\n\n:"
-      << revCert;
+      << i18n(
+             "To avoid an accidental use of this file, a colon has been inserted\n"
+             "before the 5 dashes below.  Remove this colon with a text editor\n"
+             "before importing and publishing this revocation certificate.")
+      << "\n\n:" << revCert;
     s.flush();
     qCDebug(KLEOPATRA_LOG) << "revocation certificate stored as:" << mOutputFileName;
 
     f.close();
     KMessageBox::information(d->parentWidgetOrView(),
-                             i18nc("@info", "Certificate successfully created.<br><br>"
-                                  "Note:<br>To prevent accidental import of the revocation<br>"
-                                  "it is required to manually edit the certificate<br>"
-                                  "before it can be imported."),
-                             i18n("Revocation certificate created"));
+                             i18nc("@info",
+                                   "Certificate successfully created.<br><br>"
+                                   "Note:<br>To prevent accidental import of the revocation<br>"
+                                   "it is required to manually edit the certificate<br>"
+                                   "before it can be imported."),
+                             i18nc("@title:window", "Revocation certificate created"));
 }
 
 /* Well not much to do with GnuPGProcessCommand anymore I guess.. */
@@ -140,9 +141,7 @@ void GenRevokeCommand::doStart()
 
     GnuPGProcessCommand::doStart();
 
-
-    connect(proc, &QProcess::readyReadStandardOutput,
-            this, [proc] () {
+    connect(proc, &QProcess::readyReadStandardOutput, this, [proc]() {
         while (proc->canReadLine()) {
             const QString line = QString::fromUtf8(proc->readLine()).trimmed();
             // Command-fd is a stable interface, while this is all kind of hacky we
@@ -166,17 +165,20 @@ void GenRevokeCommand::doStart()
 QStringList GenRevokeCommand::arguments() const
 {
     const Key key = d->key();
-    QStringList result;
 
-    result << gpgPath() << QStringLiteral("--command-fd") << QStringLiteral("0") << QStringLiteral("--status-fd") << QStringLiteral("1")
-           << QStringLiteral("-o") << mOutputFileName
-           << QStringLiteral("--gen-revoke")
-           << QLatin1String(key.primaryFingerprint());
-
-    return result;
+    return {
+        gpgPath(),
+        QStringLiteral("--command-fd"),
+        QStringLiteral("0"),
+        QStringLiteral("--status-fd"),
+        QStringLiteral("1"),
+        QStringLiteral("-o"),
+        mOutputFileName,
+        QStringLiteral("--gen-revoke"),
+        QLatin1String(key.primaryFingerprint()),
+    };
 }
 
-
 QString GenRevokeCommand::errorCaption() const
 {
     return i18nc("@title:window", "Error creating revocation certificate");
@@ -197,3 +199,5 @@ QString GenRevokeCommand::errorExitMessage(const QStringList &) const
     qCDebug(KLEOPATRA_LOG) << "Error exit of GenRevokeCommand";
     return QString();
 }
+
+#include "moc_genrevokecommand.cpp"
