@@ -27,6 +27,9 @@ AppearanceConfigurationPage::AppearanceConfigurationPage(QObject *parent, const
     lay->addWidget(mWidget);
 
     connect(mWidget, &AppearanceConfigWidget::changed, this, &Kleo::Config::AppearanceConfigurationPage::markAsChanged);
+
+    load();
+    setNeedsSave(false);
 }
 
 void AppearanceConfigurationPage::load()
@@ -37,6 +40,7 @@ void AppearanceConfigurationPage::load()
 void AppearanceConfigurationPage::save()
 {
     mWidget->save();
+    setNeedsSave(false);
 }
 
 void AppearanceConfigurationPage::defaults()
