@@ -18,24 +18,17 @@
 using namespace Kleo;
 using namespace Kleo::Config;
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-CryptoOperationsConfigurationPage::CryptoOperationsConfigurationPage(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
-CryptoOperationsConfigurationPage::CryptoOperationsConfigurationPage(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
-#endif
+CryptoOperationsConfigurationPage::CryptoOperationsConfigurationPage(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto lay = new QVBoxLayout(this);
-    mWidget = new CryptoOperationsConfigWidget(this);
-#else
     auto lay = new QVBoxLayout(widget());
     mWidget = new CryptoOperationsConfigWidget(widget());
-#endif
     lay->setContentsMargins(0, 0, 0, 0);
     lay->addWidget(mWidget);
     connect(mWidget, &CryptoOperationsConfigWidget::changed, this, &Kleo::Config::CryptoOperationsConfigurationPage::markAsChanged);
+
+    load();
+    setNeedsSave(false);
 }
 
 void CryptoOperationsConfigurationPage::load()
@@ -46,10 +39,12 @@ void CryptoOperationsConfigurationPage::load()
 void CryptoOperationsConfigurationPage::save()
 {
     mWidget->save();
-
+    setNeedsSave(false);
 }
 
 void CryptoOperationsConfigurationPage::defaults()
 {
     mWidget->defaults();
 }
+
+#include "moc_cryptooperationsconfigpage.cpp"
