@@ -443,6 +443,8 @@ DirectoryServicesConfigurationPage::DirectoryServicesConfigurationPage(QObject *
     : KCModule(parent, data)
     , d{new Private{this}}
 {
+    load();
+    setNeedsSave(false);
 }
 
 DirectoryServicesConfigurationPage::~DirectoryServicesConfigurationPage() = default;
@@ -455,6 +457,7 @@ void DirectoryServicesConfigurationPage::load()
 void DirectoryServicesConfigurationPage::save()
 {
     d->save();
+    setNeedsSave(false);
 }
 
 void DirectoryServicesConfigurationPage::defaults()
