@@ -12,13 +12,15 @@
 #include "encryptemailtask.h"
 
 #include <utils/input.h>
-#include <utils/output.h>
 #include <utils/kleo_assert.h>
+#include <utils/output.h>
 
 #include <Libkleo/AuditLogEntry>
+#include <Libkleo/Formatting>
 #include <Libkleo/Stl_Util>
-#include <QGpgME/Protocol>
+
 #include <QGpgME/EncryptJob>
+#include <QGpgME/Protocol>
 
 #include <gpgme++/encryptionresult.h>
 #include <gpgme++/key.h>
@@ -39,9 +41,14 @@ class EncryptEMailResult : public Task::Result
 {
     const EncryptionResult m_result;
     const AuditLogEntry m_auditLog;
+
 public:
     EncryptEMailResult(const EncryptionResult &r, const AuditLogEntry &auditLog)
-        : Task::Result(), m_result(r), m_auditLog(auditLog) {}
+        : Task::Result()
+        , m_result(r)
+        , m_auditLog(auditLog)
+    {
+    }
 
     QString overview() const override;
     QString details() const override;
@@ -60,7 +67,7 @@ QString makeResultString(const EncryptionResult &res)
     }
 
     if (err) {
-        return i18n("Encryption failed: %1", QString::fromLocal8Bit(err.asString()).toHtmlEscaped());
+        return i18n("Encryption failed: %1", Formatting::errorAsString(err).toHtmlEscaped());
     }
 
     return i18n("Encryption succeeded.");
@@ -72,6 +79,7 @@ class EncryptEMailTask::Private
 {
     friend class ::Kleo::Crypto::EncryptEMailTask;
     EncryptEMailTask *const q;
+
 public:
     explicit Private(EncryptEMailTask *qq);
 
@@ -90,21 +98,22 @@ private:
 };
 
 EncryptEMailTask::Private::Private(EncryptEMailTask *qq)
-    : q(qq),
-      input(),
-      output(),
-      job(nullptr)
+    : q(qq)
+    , input()
+    , output()
+    , job(nullptr)
 {
-
 }
 
 EncryptEMailTask::EncryptEMailTask(QObject *p)
-    : Task(p), d(new Private(this))
+    : Task(p)
+    , d(new Private(this))
 {
-
 }
 
-EncryptEMailTask::~EncryptEMailTask() {}
+EncryptEMailTask::~EncryptEMailTask()
+{
+}
 
 void EncryptEMailTask::setInput(const std::shared_ptr<Input> &input)
 {
@@ -154,7 +163,8 @@ void EncryptEMailTask::doStart()
     kleo_assert(job.get());
 
     job->start(d->recipients,
-               d->input->ioDevice(), d->output->ioDevice(),
+               d->input->ioDevice(),
+               d->output->ioDevice(),
                /*alwaysTrust=*/true);
 
     d->job = job.release();
@@ -177,15 +187,8 @@ std::unique_ptr<QGpgME::EncryptJob> EncryptEMailTask::Private::createJob(GpgME::
     if (proto == CMS && !q->asciiArmor() && !output->binaryOpt()) {
         encryptJob->setOutputIsBase64Encoded(true);
     }
-#if QGPGME_JOB_HAS_NEW_PROGRESS_SIGNALS
     connect(encryptJob.get(), &QGpgME::Job::jobProgress, q, &EncryptEMailTask::setProgress);
-#else
-    connect(encryptJob.get(), &QGpgME::Job::progress, q, [this](const QString &, int processed, int total) {
-        q->setProgress(processed, total);
-    });
-#endif
-    connect(encryptJob.get(), SIGNAL(result(GpgME::EncryptionResult,QByteArray)),
-            q, SLOT(slotResult(GpgME::EncryptionResult)));
+    connect(encryptJob.get(), SIGNAL(result(GpgME::EncryptionResult, QByteArray)), q, SLOT(slotResult(GpgME::EncryptionResult)));
     return encryptJob;
 }
 
@@ -234,4 +237,3 @@ Task::Result::VisualCode EncryptEMailResult::code() const
 }
 
 #include "moc_encryptemailtask.cpp"
-
