@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_GUI_OBJECTSPAGE_H__
-#define __KLEOPATRA_CRYPTO_GUI_OBJECTSPAGE_H__
+#pragma once
 
 #include <crypto/gui/wizardpage.h>
 
@@ -45,6 +44,3 @@ private:
 }
 }
 }
-
-#endif // __KLEOPATRA_CRYPTO_GUI_OBJECTSPAGE_H__
-
