@@ -77,13 +77,13 @@ void UpdateNotification::forceUpdateCheck(QWidget *parent)
     progress->setMinimumDuration(0);
     progress->show();
 
-    connect(progress, &QProgressDialog::canceled, [proc]() {
+    connect(progress, &QProgressDialog::canceled, proc, [proc]() {
         proc->kill();
         qCDebug(KLEOPATRA_LOG) << "Update force canceled. Output:" << QString::fromLocal8Bit(proc->readAllStandardOutput())
                                << "stderr:" << QString::fromLocal8Bit(proc->readAllStandardError());
     });
 
-    connect(proc, &QProcess::finished, [parent, progress, proc](int exitCode, QProcess::ExitStatus exitStatus) {
+    connect(proc, &QProcess::finished, progress, [parent, progress, proc](int exitCode, QProcess::ExitStatus exitStatus) {
         qCDebug(KLEOPATRA_LOG) << "Update force exited with status:" << exitStatus << "code:" << exitCode;
         delete progress;
         proc->deleteLater();
@@ -94,7 +94,7 @@ void UpdateNotification::forceUpdateCheck(QWidget *parent)
 
     proc->start();
 }
-
+#ifdef Q_OS_WIN
 /* Extract the actual version number (conforming to the semanticversioning spec)
  * from the Version strings which might be used for Gpg4win / GnuPG VS-Desktop
  * which are optionally prefixed with some text followed by a dash
@@ -107,6 +107,7 @@ static const QByteArray extractVersionNumber(const QString &versionString)
     const auto current = match.hasMatch() ? match.captured(1) : versionString;
     return current.toUtf8();
 }
+#endif
 
 void UpdateNotification::checkUpdate(QWidget *parent, bool force)
 {
